@@ -8,6 +8,7 @@ from datetime import datetime, timedelta
 from django.db import models
 from django.conf import settings
 from django.utils import simplejson
+from django.contrib.auth.models import User
 
 
 class AuthKeyManager(models.Manager):
@@ -25,7 +26,7 @@ class AuthKeyManager(models.Manager):
             key.expired = datetime.now() + timedelta(seconds=settings.URLAUTH_AUTHKEY_TIMEOUT)
 
         if 'onetime' in kwargs:
-            key.onetime = kwargs['onetime']
+            key.onetime = kwargs.pop('onetime')
 
         source = '%s%d%d' % (settings.SECRET_KEY, time.time(), id({}))
         key.id = sha1(source).hexdigest()
@@ -36,7 +37,7 @@ class AuthKeyManager(models.Manager):
 
 class AuthKey(models.Model):
     id = models.CharField(max_length=40, primary_key=True)
-    uid = models.PositiveIntegerField()
+    uid = models.PositiveIntegerField(null=True)
     expired = models.DateTimeField()
     created = models.DateTimeField(auto_now_add=True)
     onetime = models.BooleanField(blank=True, default=True)
@@ -50,3 +51,9 @@ class AuthKey(models.Model):
     @property
     def extra(self):
         return simplejson.loads(self.data)
+
+    def get_user(self):
+        if self.uid:
+            return User.objects.get(pk=self.uid)
+        else:
+            return None
