@@ -68,6 +68,22 @@ class UrlauthTestCase(TestCase):
         self.assertEqual(url, '%s&%s=%s' % (clean_url,
                                             settings.URLAUTH_AUTHKEY_NAME, key.id))
 
+        # Test url with hash
+        AuthKey.objects.all().delete()
+        clean_url = 'http://ya.ru#hash'
+        url = wrap_url(clean_url, uid=self.user.pk, expired=expired)
+        key = AuthKey.objects.get()
+        self.assertEqual(url, 'http://ya.ru?%s=%s#hash' % (settings.URLAUTH_AUTHKEY_NAME,
+                                                           key.id))
+
+        # Test url with hash and non-empty querystring
+        AuthKey.objects.all().delete()
+        clean_url = 'http://ya.ru?foo=bar#hash'
+        url = wrap_url(clean_url, uid=self.user.pk, expired=expired)
+        key = AuthKey.objects.get()
+        self.assertEqual(url, 'http://ya.ru?foo=bar&%s=%s#hash' % (settings.URLAUTH_AUTHKEY_NAME,
+                                                           key.id))
+
     def test_validate_key(self):
         expired = datetime.now() - timedelta(seconds=1)
         key = AuthKey.objects.create_key(uid=self.user.pk, expired=expired, foo='bar')
