@@ -22,9 +22,15 @@ def wrap_url(url, **kwargs):
     if not 'uid' in kwargs:
         raise Exception('wrap_url function requires uid name argument')
 
-    hash = AuthKey.objects.create_key(**kwargs)
+    key_id = AuthKey.objects.create_key(**kwargs)
     clue = '?' in url and '&' or '?'
-    url = '%s%s%s=%s' % (url, clue, settings.URLAUTH_AUTHKEY_NAME, hash)
+    parts = url.rsplit('#', 1)
+    if len(parts) > 1:
+        url, hash = parts
+        hash = '#%s' % hash
+    else:
+        hash = ''
+    url = '%s%s%s=%s%s' % (url, clue, settings.URLAUTH_AUTHKEY_NAME, key_id, hash)
     return url
 
 
